@@ -1,6 +1,5 @@
 use crate::abi_decoder::ABIDecoder;
 use crate::abi_encoder::ABIEncoder;
-use crate::errors::Error;
 use crate::parameters::{CallParameters, TxParameters};
 use crate::script::Script;
 use anyhow::Result;
@@ -13,6 +12,7 @@ use fuel_types::{Bytes32, Salt, Word};
 use fuel_vm::consts::{REG_CGAS, REG_ONE};
 use fuel_vm::prelude::Contract as FuelContract;
 use fuel_vm::script_with_data_offset;
+use fuels_core::errors::Error;
 use fuels_core::{
     constants::DEFAULT_COIN_AMOUNT, constants::WORD_SIZE, Detokenize, Selector, Token,
 };
@@ -339,10 +339,12 @@ impl Contract {
 
     // Returns true if the method call takes custom inputs or has more than one argument. This is used to determine whether we need to compute the `call_data_offset`.
     fn should_compute_call_data_offset(args: &[Token]) -> bool {
-        match args
-            .iter()
-            .any(|t| matches!(t, Token::Struct(_) | Token::Enum(_)))
-        {
+        match args.iter().any(|t| {
+            matches!(
+                t,
+                Token::Struct(_) | Token::Enum(_) | Token::B256(_) | Token::Tuple(_)
+            )
+        }) {
             true => true,
             false => args.len() > 1,
         }
@@ -553,8 +555,14 @@ where
         mut receipts: Vec<Receipt>,
         output_params: &[ParamType],
     ) -> Result<(Vec<Token>, Vec<Receipt>), Error> {
-        // Right now we only support methods with a single return type.
-        // Soon we'll support tuple as a return type and we'll have to update the logic in here.
+        // Multiple returns are handled as one `Tuple` (which has its own `ParamType`), so getting
+        // more than one output param is an error.
+        if output_params.len() != 1 {
+            return Err(Error::InvalidType(format!(
+                "Received too many output params (expected 1 got {})",
+                output_params.len()
+            )));
+        }
         let output_param = output_params[0].clone();
         // If the method's return type is bigger than a single `WORD`, the returned value
         // is stored in `ReturnData.data`, otherwise, it's stored in `Return.val`.
