@@ -1,6 +1,6 @@
 use fuel_tx::AssetId;
 use fuels_core::constants::{
-    DEFAULT_BYTE_PRICE, DEFAULT_GAS_LIMIT, DEFAULT_GAS_PRICE, NATIVE_ASSET_ID,
+    DEFAULT_BYTE_PRICE, DEFAULT_GAS_LIMIT, DEFAULT_GAS_PRICE, DEFAULT_MATURITY, NATIVE_ASSET_ID,
 };
 
 #[derive(Debug)]
@@ -8,6 +8,7 @@ pub struct TxParameters {
     pub gas_price: u64,
     pub gas_limit: u64,
     pub byte_price: u64,
+    pub maturity: u32,
 }
 
 #[derive(Debug)]
@@ -40,16 +41,24 @@ impl Default for TxParameters {
             gas_price: DEFAULT_GAS_PRICE,
             gas_limit: DEFAULT_GAS_LIMIT,
             byte_price: DEFAULT_BYTE_PRICE,
+            // By default, transaction is immediately valid
+            maturity: DEFAULT_MATURITY,
         }
     }
 }
 
 impl TxParameters {
-    pub fn new(gas_price: Option<u64>, gas_limit: Option<u64>, byte_price: Option<u64>) -> Self {
+    pub fn new(
+        gas_price: Option<u64>,
+        gas_limit: Option<u64>,
+        byte_price: Option<u64>,
+        maturity: Option<u32>,
+    ) -> Self {
         Self {
             gas_price: gas_price.unwrap_or(DEFAULT_GAS_PRICE),
             gas_limit: gas_limit.unwrap_or(DEFAULT_GAS_LIMIT),
             byte_price: byte_price.unwrap_or(DEFAULT_BYTE_PRICE),
+            maturity: maturity.unwrap_or(DEFAULT_MATURITY),
         }
     }
 }
