@@ -1,7 +1,7 @@
-use crate::errors::Error;
 use anyhow::Result;
 use fuel_gql_client::client::{types::TransactionStatus, FuelClient};
 use fuel_tx::{Receipt, Transaction};
+use fuels_core::errors::Error;
 
 /// Script is a very thin layer on top of fuel-client with some
 /// extra functionalities needed and provided by the SDK.
